@@ -115,7 +115,7 @@ groupwise_auth_loop (CamelService *service,
 	guint32 prompt_flags = CAMEL_SESSION_PASSWORD_SECRET;
 	const gchar *scheme;
 	EGwConnectionErrors errors = {E_GW_CONNECTION_STATUS_INVALID_OBJECT, NULL};
-	guint16 soap_port;
+	const gchar *soap_port;
 
 	url = camel_service_get_camel_url (service);
 	settings = camel_service_get_settings (service);
@@ -132,7 +132,7 @@ groupwise_auth_loop (CamelService *service,
 		scheme = "https";
 
 	uri = g_strdup_printf (
-		"%s://%s:%u/soap", scheme, priv->server_name, soap_port);
+		"%s://%s:%s/soap", scheme, priv->server_name, soap_port);
 
 	url->passwd = NULL;
 
@@ -202,14 +202,14 @@ check_for_connection (CamelService *service,
 	ai = camel_getaddrinfo(priv->server_name, "groupwise", &hints, cancellable, &local_error);
 	if (ai == NULL && g_error_matches (local_error, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
 		gchar *port_string;
-		guint16 soap_port;
+		const gchar *soap_port;
 
 		g_clear_error (&local_error);
 
 		soap_port = camel_groupwise_settings_get_soap_port (
 			CAMEL_GROUPWISE_SETTINGS (settings));
 
-		port_string = g_strdup_printf ("%u", soap_port);
+		port_string = g_strdup(soap_port);
 		ai = camel_getaddrinfo (
 			priv->server_name, port_string, &hints,
 			cancellable, &local_error);
